Class: Google::Apis::BigquerydatapolicyV2::AddGranteesRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquerydatapolicy_v2/classes.rb,
lib/google/apis/bigquerydatapolicy_v2/representations.rb,
lib/google/apis/bigquerydatapolicy_v2/representations.rb

Overview

Request message for the AddGrantees method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AddGranteesRequest

Returns a new instance of AddGranteesRequest.



38
39
40
# File 'lib/google/apis/bigquerydatapolicy_v2/classes.rb', line 38

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#granteesArray<String>

Required. IAM principal that should be granted Fine Grained Access to the underlying data goverened by the data policy. The target data policy is determined by the data_policy field. Uses the IAM V2 principal syntax. Supported principal types: * User * Group * Service account Corresponds to the JSON property grantees

Returns:

  • (Array<String>)


36
37
38
# File 'lib/google/apis/bigquerydatapolicy_v2/classes.rb', line 36

def grantees
  @grantees
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



43
44
45
# File 'lib/google/apis/bigquerydatapolicy_v2/classes.rb', line 43

def update!(**args)
  @grantees = args[:grantees] if args.key?(:grantees)
end