Class: Google::Apis::BigquerydatapolicyV2::DataGovernanceTag

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquerydatapolicy_v2/classes.rb,
lib/google/apis/bigquerydatapolicy_v2/representations.rb,
lib/google/apis/bigquerydatapolicy_v2/representations.rb

Overview

Data Governance tag This is a namespaced name specifying the key and the value. For example: project-id/pii/sensitive.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DataGovernanceTag

Returns a new instance of DataGovernanceTag.



264
265
266
# File 'lib/google/apis/bigquerydatapolicy_v2/classes.rb', line 264

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#keyString

Optional. Tag keys are globally unique. Tag key is expected to be in the namespaced format, for example parent-id/pii where parent-id is the ID of the parent organization or project resource for this tag key. Corresponds to the JSON property key

Returns:

  • (String)


257
258
259
# File 'lib/google/apis/bigquerydatapolicy_v2/classes.rb', line 257

def key
  @key
end

#valueString

Optional. Specifies the tag value as the short name, for example sensitive. Corresponds to the JSON property value

Returns:

  • (String)


262
263
264
# File 'lib/google/apis/bigquerydatapolicy_v2/classes.rb', line 262

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



269
270
271
272
# File 'lib/google/apis/bigquerydatapolicy_v2/classes.rb', line 269

def update!(**args)
  @key = args[:key] if args.key?(:key)
  @value = args[:value] if args.key?(:value)
end