Class: Google::Apis::BigquerydatapolicyV2::ListDataPoliciesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquerydatapolicy_v2/classes.rb,
lib/google/apis/bigquerydatapolicy_v2/representations.rb,
lib/google/apis/bigquerydatapolicy_v2/representations.rb

Overview

Response message for the ListDataPolicies method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListDataPoliciesResponse

Returns a new instance of ListDataPoliciesResponse.



515
516
517
# File 'lib/google/apis/bigquerydatapolicy_v2/classes.rb', line 515

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#data_policiesArray<Google::Apis::BigquerydatapolicyV2::DataPolicy>

Data policies that belong to the requested project. Corresponds to the JSON property dataPolicies



507
508
509
# File 'lib/google/apis/bigquerydatapolicy_v2/classes.rb', line 507

def data_policies
  @data_policies
end

#next_page_tokenString

Token used to retrieve the next page of results, or empty if there are no more results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


513
514
515
# File 'lib/google/apis/bigquerydatapolicy_v2/classes.rb', line 513

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



520
521
522
523
# File 'lib/google/apis/bigquerydatapolicy_v2/classes.rb', line 520

def update!(**args)
  @data_policies = args[:data_policies] if args.key?(:data_policies)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end