Class: Google::Apis::BigquerydatapolicyV2::RemoveGranteesRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquerydatapolicy_v2/classes.rb,
lib/google/apis/bigquerydatapolicy_v2/representations.rb,
lib/google/apis/bigquerydatapolicy_v2/representations.rb

Overview

Request message for the RemoveGrantees method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RemoveGranteesRequest

Returns a new instance of RemoveGranteesRequest.



634
635
636
# File 'lib/google/apis/bigquerydatapolicy_v2/classes.rb', line 634

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#granteesArray<String>

Required. IAM principal that should be revoked from Fine Grained Access to the underlying data goverened by the data policy. The target data policy is determined by the data_policy field. Uses the IAM V2 principal syntax. Supported principal types: * User * Group * Service account Corresponds to the JSON property grantees

Returns:

  • (Array<String>)


632
633
634
# File 'lib/google/apis/bigquerydatapolicy_v2/classes.rb', line 632

def grantees
  @grantees
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



639
640
641
# File 'lib/google/apis/bigquerydatapolicy_v2/classes.rb', line 639

def update!(**args)
  @grantees = args[:grantees] if args.key?(:grantees)
end