Module: Google::Apis::BigquerydatapolicyV2
- Defined in:
- lib/google/apis/bigquerydatapolicy_v2.rb,
lib/google/apis/bigquerydatapolicy_v2/classes.rb,
lib/google/apis/bigquerydatapolicy_v2/service.rb,
lib/google/apis/bigquerydatapolicy_v2/gem_version.rb,
lib/google/apis/bigquerydatapolicy_v2/representations.rb
Overview
BigQuery Data Policy API
Allows users to manage BigQuery data policies.
Defined Under Namespace
Classes: AddGranteesRequest, AuditConfig, AuditLogConfig, BigQueryDataPolicyServiceService, Binding, CreateDataPolicyRequest, DataGovernanceTag, DataMaskingPolicy, DataPolicy, Empty, Expr, GetIamPolicyRequest, GetPolicyOptions, ListDataPoliciesResponse, Policy, RemoveGranteesRequest, SetIamPolicyRequest, TestIamPermissionsRequest, TestIamPermissionsResponse
Constant Summary collapse
- GEM_VERSION =
Version of the google-apis-bigquerydatapolicy_v2 gem
"0.2.0"- GENERATOR_VERSION =
Version of the code generator used to generate this client
"0.18.0"- REVISION =
Revision of the discovery document this client was generated from
"20260415"- VERSION =
Version of the BigQuery Data Policy API this client connects to. This is NOT the gem version.
'V2'- AUTH_BIGQUERY =
View and manage your data in Google BigQuery and see the email address for your Google Account
'https://www.googleapis.com/auth/bigquery'- AUTH_CLOUD_PLATFORM =
See, edit, configure, and delete your Google Cloud data and see the email address for your Google Account.
'https://www.googleapis.com/auth/cloud-platform'