Class: Google::Apis::BigquerydatapolicyV2::DataPolicy
- Inherits:
-
Object
- Object
- Google::Apis::BigquerydatapolicyV2::DataPolicy
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigquerydatapolicy_v2/classes.rb,
lib/google/apis/bigquerydatapolicy_v2/representations.rb,
lib/google/apis/bigquerydatapolicy_v2/representations.rb
Overview
Represents the label-policy binding.
Instance Attribute Summary collapse
-
#data_governance_tag ⇒ Google::Apis::BigquerydatapolicyV2::DataGovernanceTag
Data Governance tag This is a namespaced name specifying the key and the value.
-
#data_masking_policy ⇒ Google::Apis::BigquerydatapolicyV2::DataMaskingPolicy
The policy used to specify data masking rule.
-
#data_policy_id ⇒ String
Output only.
-
#data_policy_type ⇒ String
Required.
-
#etag ⇒ String
The etag for this Data Policy.
-
#grantees ⇒ Array<String>
Optional.
-
#name ⇒ String
Identifier.
-
#policy_tag ⇒ String
Output only.
-
#version ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DataPolicy
constructor
A new instance of DataPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DataPolicy
Returns a new instance of DataPolicy.
365 366 367 |
# File 'lib/google/apis/bigquerydatapolicy_v2/classes.rb', line 365 def initialize(**args) update!(**args) end |
Instance Attribute Details
#data_governance_tag ⇒ Google::Apis::BigquerydatapolicyV2::DataGovernanceTag
Data Governance tag This is a namespaced name specifying the key and the value.
For example: project-id/pii/sensitive.
Corresponds to the JSON property dataGovernanceTag
310 311 312 |
# File 'lib/google/apis/bigquerydatapolicy_v2/classes.rb', line 310 def data_governance_tag @data_governance_tag end |
#data_masking_policy ⇒ Google::Apis::BigquerydatapolicyV2::DataMaskingPolicy
The policy used to specify data masking rule.
Corresponds to the JSON property dataMaskingPolicy
315 316 317 |
# File 'lib/google/apis/bigquerydatapolicy_v2/classes.rb', line 315 def data_masking_policy @data_masking_policy end |
#data_policy_id ⇒ String
Output only. User-assigned (human readable) ID of the data policy that needs
to be unique within a project. Used as data_policy_id in part of the
resource name.
Corresponds to the JSON property dataPolicyId
322 323 324 |
# File 'lib/google/apis/bigquerydatapolicy_v2/classes.rb', line 322 def data_policy_id @data_policy_id end |
#data_policy_type ⇒ String
Required. Type of data policy.
Corresponds to the JSON property dataPolicyType
327 328 329 |
# File 'lib/google/apis/bigquerydatapolicy_v2/classes.rb', line 327 def data_policy_type @data_policy_type end |
#etag ⇒ String
The etag for this Data Policy. This field is used for UpdateDataPolicy calls.
If Data Policy exists, this field is required and must match the server's etag.
It will also be populated in the response of GetDataPolicy, CreateDataPolicy,
and UpdateDataPolicy calls.
Corresponds to the JSON property etag
335 336 337 |
# File 'lib/google/apis/bigquerydatapolicy_v2/classes.rb', line 335 def etag @etag end |
#grantees ⇒ Array<String>
Optional. The list of IAM principals that have Fine Grained Access to the
underlying data goverened by this data policy. Uses the IAM V2 principal
syntax Only
supports principal types users, groups, serviceaccounts, cloudidentity. This
field is supported in V2 Data Policy only. In case of V1 data policies (i.e.
verion = 1 and policy_tag is set), this field is not populated.
Corresponds to the JSON property grantees
345 346 347 |
# File 'lib/google/apis/bigquerydatapolicy_v2/classes.rb', line 345 def grantees @grantees end |
#name ⇒ String
Identifier. Resource name of this data policy, in the format of projects/
project_number/locations/location_id/dataPolicies/data_policy_id`.
Corresponds to the JSON propertyname`
351 352 353 |
# File 'lib/google/apis/bigquerydatapolicy_v2/classes.rb', line 351 def name @name end |
#policy_tag ⇒ String
Output only. Policy tag resource name, in the format of projects/
project_number/locations/location_id/taxonomies/taxonomy_id/policyTags/
policyTag_id`. policy_tag is supported only for V1 data policies.
Corresponds to the JSON propertypolicyTag`
358 359 360 |
# File 'lib/google/apis/bigquerydatapolicy_v2/classes.rb', line 358 def policy_tag @policy_tag end |
#version ⇒ String
Output only. The version of the Data Policy resource.
Corresponds to the JSON property version
363 364 365 |
# File 'lib/google/apis/bigquerydatapolicy_v2/classes.rb', line 363 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
370 371 372 373 374 375 376 377 378 379 380 |
# File 'lib/google/apis/bigquerydatapolicy_v2/classes.rb', line 370 def update!(**args) @data_governance_tag = args[:data_governance_tag] if args.key?(:data_governance_tag) @data_masking_policy = args[:data_masking_policy] if args.key?(:data_masking_policy) @data_policy_id = args[:data_policy_id] if args.key?(:data_policy_id) @data_policy_type = args[:data_policy_type] if args.key?(:data_policy_type) @etag = args[:etag] if args.key?(:etag) @grantees = args[:grantees] if args.key?(:grantees) @name = args[:name] if args.key?(:name) @policy_tag = args[:policy_tag] if args.key?(:policy_tag) @version = args[:version] if args.key?(:version) end |